# snowbank
A python package to easily manage and integrate snowbank apis 

# Installation  

``` pip install snowbank ```


Goto the snowbank website https://www.snowbank.me login and get your developer token, use the token for authentication.


# Status Codes 



| Code | Description                      |
|------|----------------------------------|
| 0    | Success                          |
| 1    | Authentication Failed            |
| 2    | Token not found                  |
| 3    | Generating Seed failed!          |
| 4    | Wallet Initiation failed!        |
| 5    | Unauthorized access/ Bad Request |
| 6    | Balance fetching failed!         |
| 7    | User not found                   |
| 8    | Parameter are missing            |
| 9    | Failed on fetching address       |
| 10   | Failed on fetching public key    |
| 11   | Failed to update in DB           |
| 12   | Failed to create failed          |
| 13   | Failed to start channel          |
| 14   | Payment declined!                |
| 15   | API calls limit exceeds          |
| 16   | User limit exceeds               |
